import { Balances, ControlClaim, HypernetLink, PublicIdentifier, PullPayment, PushPayment, Payment, PaymentId, GatewayUrl, Signature, AcceptPaymentError, BlockchainUnavailableError, VectorError, BalancesUnavailableError, InsufficientBalanceError, GatewayValidationError, PersistenceError, GatewayConnectorError, ProxyError, InvalidParametersError, IHypernetCore, GatewayAuthorizationDeniedError, BigNumberString, MessagingError, RouterChannelUnknownError, ActiveStateChannel, ChainId, GatewayTokenInfo, GatewayRegistrationFilter, GatewayRegistrationInfo, Proposal, EProposalVoteSupport, ProposalVoteReceipt, Registry, RegistryEntry, RegistryParams, RegistryPermissionError, ERegistrySortOrder, RegistryFactoryContractError, NonFungibleRegistryContractError, HypernetGovernorContractError, ERC20ContractError, InvalidPaymentError, TransferCreationError, PaymentStakeError, TransferResolutionError, EthereumAccountAddress, EthereumContractAddress, ProviderId, TokenInformation, RegistryModule, BatchModuleContractError, InvalidPaymentIdError } from "@hypernetlabs/objects";
import { ParentProxy } from "@hypernetlabs/utils";
import { Result, ResultAsync } from "neverthrow";
import { Subject } from "rxjs";
export default class HypernetIFrameProxy extends ParentProxy implements IHypernetCore {
    protected element: HTMLElement | null;
    protected iframeUrl: string;
    protected iframeName: string;
    protected coreInitialized: boolean;
    protected isInControl: boolean;
    protected waitInitializedPromise: Promise<void>;
    protected _handshakePromise: Promise<void> | null;
    constructor(element: HTMLElement | null, iframeUrl: string, iframeName: string);
    finalizePullPayment(_paymentId: PaymentId, _finalAmount: BigNumberString): Promise<HypernetLink>;
    initialized(): Result<boolean, never>;
    waitInitialized(): ResultAsync<void, never>;
    inControl(): Result<boolean, never>;
    getEthereumAccounts(): ResultAsync<EthereumAccountAddress[], BlockchainUnavailableError | ProxyError>;
    initialize(): ResultAsync<void, MessagingError | BlockchainUnavailableError | VectorError | RouterChannelUnknownError | GatewayConnectorError | GatewayValidationError | ProxyError>;
    getPublicIdentifier(): ResultAsync<PublicIdentifier, ProxyError>;
    getActiveStateChannels(): ResultAsync<ActiveStateChannel[], VectorError | BlockchainUnavailableError | PersistenceError | ProxyError>;
    createStateChannel(routerPublicIdentifiers: PublicIdentifier[], chainId: ChainId): ResultAsync<ActiveStateChannel, VectorError | BlockchainUnavailableError | PersistenceError | ProxyError>;
    depositFunds(channelAddress: EthereumContractAddress, assetAddress: EthereumContractAddress, amount: BigNumberString): ResultAsync<Balances, BalancesUnavailableError | BlockchainUnavailableError | VectorError | Error>;
    withdrawFunds(channelAddress: EthereumContractAddress, assetAddress: EthereumContractAddress, amount: BigNumberString, destinationAddress: EthereumAccountAddress): ResultAsync<Balances, BalancesUnavailableError | BlockchainUnavailableError | VectorError | Error>;
    getBalances(): ResultAsync<Balances, BalancesUnavailableError | VectorError | ProxyError>;
    getLinks(): ResultAsync<HypernetLink[], VectorError | Error>;
    getActiveLinks(): ResultAsync<HypernetLink[], VectorError | Error>;
    acceptOffer(paymentId: PaymentId): ResultAsync<Payment, TransferCreationError | VectorError | BalancesUnavailableError | BlockchainUnavailableError | InvalidPaymentError | InvalidParametersError | PaymentStakeError | TransferResolutionError | AcceptPaymentError | InsufficientBalanceError | ProxyError>;
    pullFunds(paymentId: PaymentId, amount: BigNumberString): ResultAsync<Payment, VectorError | Error>;
    repairPayments(paymentIds: PaymentId[]): ResultAsync<void, VectorError | BlockchainUnavailableError | InvalidPaymentError | InvalidParametersError | TransferResolutionError | InvalidPaymentIdError | ProxyError>;
    mintTestToken(amount: BigNumberString): ResultAsync<void, BlockchainUnavailableError | ProxyError>;
    authorizeGateway(gatewayUrl: GatewayUrl): ResultAsync<void, GatewayValidationError | PersistenceError | VectorError | ProxyError>;
    deauthorizeGateway(gatewayUrl: GatewayUrl): ResultAsync<void, PersistenceError | ProxyError | GatewayAuthorizationDeniedError>;
    getAuthorizedGateways(): ResultAsync<Map<GatewayUrl, Signature>, PersistenceError | VectorError | ProxyError>;
    getAuthorizedGatewaysConnectorsStatus(): ResultAsync<Map<GatewayUrl, boolean>, PersistenceError | VectorError | ProxyError>;
    getGatewayTokenInfo(gatewayUrls: GatewayUrl[]): ResultAsync<Map<GatewayUrl, GatewayTokenInfo[]>, PersistenceError | ProxyError | GatewayAuthorizationDeniedError>;
    getGatewayRegistrationInfo(filter?: GatewayRegistrationFilter): ResultAsync<GatewayRegistrationInfo[], PersistenceError | VectorError | ProxyError>;
    displayGatewayIFrame(gatewayUrl: GatewayUrl): ResultAsync<void, GatewayConnectorError | PersistenceError | VectorError | ProxyError>;
    closeGatewayIFrame(gatewayUrl: GatewayUrl): ResultAsync<void, GatewayConnectorError | PersistenceError | VectorError | ProxyError>;
    providePrivateCredentials(privateKey: string | null, mnemonic: string | null): ResultAsync<void, InvalidParametersError | ProxyError>;
    getProposals(pageNumber: number, pageSize: number): ResultAsync<Proposal[], HypernetGovernorContractError | ProxyError>;
    createProposal(name: string, symbol: string, owner: EthereumAccountAddress, enumerable: boolean): ResultAsync<Proposal, HypernetGovernorContractError | ProxyError>;
    delegateVote(delegateAddress: EthereumAccountAddress, amount: number | null): ResultAsync<void, ERC20ContractError | ProxyError>;
    getProposalDetails(proposalId: string): ResultAsync<Proposal, HypernetGovernorContractError | ProxyError>;
    castVote(proposalId: string, support: EProposalVoteSupport): ResultAsync<Proposal, HypernetGovernorContractError | ProxyError>;
    getProposalVotesReceipt(proposalId: string, voterAddress: EthereumAccountAddress): ResultAsync<ProposalVoteReceipt, HypernetGovernorContractError | ProxyError>;
    getRegistries(pageNumber: number, pageSize: number, sortOrder: ERegistrySortOrder): ResultAsync<Registry[], RegistryFactoryContractError | NonFungibleRegistryContractError | ProxyError>;
    getRegistryByName(registryNames: string[]): ResultAsync<Map<string, Registry>, RegistryFactoryContractError | NonFungibleRegistryContractError | ProxyError>;
    getRegistryByAddress(registryAddresses: EthereumContractAddress[]): ResultAsync<Map<EthereumContractAddress, Registry>, RegistryFactoryContractError | NonFungibleRegistryContractError | ProxyError>;
    getRegistryEntriesTotalCount(registryNames: string[]): ResultAsync<Map<string, number>, RegistryFactoryContractError | NonFungibleRegistryContractError | ProxyError>;
    getRegistryEntries(registryName: string, pageNumber: number, pageSize: number, sortOrder: ERegistrySortOrder): ResultAsync<RegistryEntry[], RegistryFactoryContractError | NonFungibleRegistryContractError | ProxyError>;
    getRegistryEntryDetailByTokenId(registryName: string, tokenId: number): ResultAsync<RegistryEntry, RegistryFactoryContractError | NonFungibleRegistryContractError | ProxyError>;
    updateRegistryEntryTokenURI(registryName: string, tokenId: number, registrationData: string): ResultAsync<RegistryEntry, BlockchainUnavailableError | RegistryFactoryContractError | NonFungibleRegistryContractError | RegistryPermissionError | ProxyError>;
    updateRegistryEntryLabel(registryName: string, tokenId: number, label: string): ResultAsync<RegistryEntry, BlockchainUnavailableError | RegistryFactoryContractError | NonFungibleRegistryContractError | RegistryPermissionError | ProxyError>;
    queueProposal(proposalId: string): ResultAsync<Proposal, HypernetGovernorContractError | ProxyError>;
    cancelProposal(proposalId: string): ResultAsync<Proposal, HypernetGovernorContractError | ProxyError>;
    executeProposal(proposalId: string): ResultAsync<Proposal, HypernetGovernorContractError | ProxyError>;
    getProposalsCount(): ResultAsync<number, HypernetGovernorContractError | ProxyError>;
    getProposalThreshold(): ResultAsync<number, HypernetGovernorContractError | ProxyError>;
    getVotingPower(account: EthereumAccountAddress): ResultAsync<number, HypernetGovernorContractError | ERC20ContractError | ProxyError>;
    getHyperTokenBalance(account: EthereumAccountAddress): ResultAsync<number, ERC20ContractError | ProxyError>;
    getNumberOfRegistries(): ResultAsync<number, RegistryFactoryContractError | NonFungibleRegistryContractError | ProxyError>;
    updateRegistryParams(registryParams: RegistryParams): ResultAsync<Registry, NonFungibleRegistryContractError | RegistryFactoryContractError | BlockchainUnavailableError | RegistryPermissionError | ProxyError>;
    createRegistryEntry(registryName: string, newRegistryEntry: RegistryEntry): ResultAsync<void, NonFungibleRegistryContractError | RegistryFactoryContractError | BlockchainUnavailableError | RegistryPermissionError | ProxyError>;
    transferRegistryEntry(registryName: string, tokenId: number, transferToAddress: EthereumAccountAddress): ResultAsync<RegistryEntry, NonFungibleRegistryContractError | RegistryFactoryContractError | BlockchainUnavailableError | RegistryPermissionError | ProxyError>;
    burnRegistryEntry(registryName: string, tokenId: number): ResultAsync<void, NonFungibleRegistryContractError | RegistryFactoryContractError | BlockchainUnavailableError | RegistryPermissionError | ProxyError>;
    createRegistryByToken(name: string, symbol: string, registrarAddress: EthereumAccountAddress, enumerable: boolean): ResultAsync<void, RegistryFactoryContractError | ERC20ContractError | ProxyError>;
    grantRegistrarRole(registryName: string, address: EthereumAccountAddress | EthereumContractAddress): ResultAsync<void, NonFungibleRegistryContractError | RegistryFactoryContractError | BlockchainUnavailableError | RegistryPermissionError | ProxyError>;
    revokeRegistrarRole(registryName: string, address: EthereumAccountAddress): ResultAsync<void, NonFungibleRegistryContractError | RegistryFactoryContractError | BlockchainUnavailableError | RegistryPermissionError | ProxyError>;
    renounceRegistrarRole(registryName: string, address: EthereumAccountAddress): ResultAsync<void, NonFungibleRegistryContractError | RegistryFactoryContractError | BlockchainUnavailableError | RegistryPermissionError | ProxyError>;
    provideProviderId(providerId: ProviderId): ResultAsync<void, InvalidParametersError | ProxyError>;
    getTokenInformation(): ResultAsync<TokenInformation[], ProxyError>;
    getTokenInformationForChain(chainId: ChainId): ResultAsync<TokenInformation[], ProxyError>;
    getTokenInformationByAddress(tokenAddress: EthereumContractAddress): ResultAsync<TokenInformation | null, ProxyError>;
    getRegistryEntryByOwnerAddress(registryName: string, ownerAddress: EthereumAccountAddress, index: number): ResultAsync<RegistryEntry | null, RegistryFactoryContractError | NonFungibleRegistryContractError | ProxyError>;
    getRegistryModules(): ResultAsync<RegistryModule[], RegistryFactoryContractError | ProxyError>;
    createBatchRegistryEntry(registryName: string, newRegistryEntries: RegistryEntry[]): ResultAsync<void, BatchModuleContractError | RegistryFactoryContractError | NonFungibleRegistryContractError | ProxyError>;
    private _displayCoreIFrame;
    private _closeCoreIFrame;
    /**
     * Observables for seeing what's going on
     */
    onControlClaimed: Subject<ControlClaim>;
    onControlYielded: Subject<ControlClaim>;
    onPushPaymentSent: Subject<PushPayment>;
    onPullPaymentSent: Subject<PullPayment>;
    onPushPaymentUpdated: Subject<PushPayment>;
    onPullPaymentUpdated: Subject<PullPayment>;
    onPushPaymentReceived: Subject<PushPayment>;
    onPullPaymentReceived: Subject<PullPayment>;
    onPushPaymentDelayed: Subject<PushPayment>;
    onPullPaymentDelayed: Subject<PullPayment>;
    onPushPaymentCanceled: Subject<PushPayment>;
    onPullPaymentCanceled: Subject<PullPayment>;
    onBalancesChanged: Subject<Balances>;
    onCeramicAuthenticationStarted: Subject<void>;
    onCeramicAuthenticationSucceeded: Subject<void>;
    onCeramicFailed: Subject<Error>;
    onGatewayAuthorized: Subject<GatewayUrl>;
    onGatewayDeauthorizationStarted: Subject<GatewayUrl>;
    onAuthorizedGatewayUpdated: Subject<GatewayUrl>;
    onAuthorizedGatewayActivationFailed: Subject<GatewayUrl>;
    onGatewayIFrameDisplayRequested: Subject<GatewayUrl>;
    onGatewayIFrameCloseRequested: Subject<GatewayUrl>;
    onCoreIFrameDisplayRequested: Subject<void>;
    onCoreIFrameCloseRequested: Subject<void>;
    onInitializationRequired: Subject<void>;
    onPrivateCredentialsRequested: Subject<void>;
    onWalletConnectOptionsDisplayRequested: Subject<void>;
    onStateChannelCreated: Subject<ActiveStateChannel>;
    onChainConnected: Subject<ChainId>;
    onGovernanceChainConnected: Subject<ChainId>;
    onChainChanged: Subject<ChainId>;
    onAccountChanged: Subject<EthereumAccountAddress>;
    onGovernanceChainChanged: Subject<ChainId>;
    onGovernanceAccountChanged: Subject<EthereumAccountAddress>;
}
//# sourceMappingURL=HypernetIFrameProxy.d.ts.map